use v6.c;
module LoadFromInsideAModule {
    use Foo;
}
